__all__ = ['retry']

def retry(channel, service, body, headers, settings, ack):
    try:
        assert headers['retry-count'] < settings['services'][service]['retry-count']
    except AssertionError:
        ack.set_result(True)
        return
    except KeyError:
        headers['retry-count'] = 1
    else:
        headers['retry-count'] += 1

    from nrask.rmq import BasicProperties
    channel.basic_publish(
        exchange=settings['exchange']['retry'],
        routing_key=settings['services'][service]['rk'],
        body=body,
        properties=BasicProperties(
            headers=headers
        )
    )
    ack.set_result(True)



from nrask.raven import Raven
import os

class Debug(object):
    enabled = (os.getenv('NRASK_DEBUG') == '1')

    def __init__(self, name):
        self.name = name

    def log(self, msg):
        try:
            assert self.__logger
        except (AssertionError, AttributeError):
            self.__logger = Raven('[debug] ' + self.name)

        try:
            assert self.enabled
        except AssertionError:
            pass
        else:
            self.__logger.info(msg)



from setuptools import find_packages,setup

setup(
    description='Viking Makt Framework',
    install_requires=[
        'pika',
        'tornado',
        'simplejson',
        'colorlog',
        'bencode',
    ],
    license='https://bitbucket.org/habboi/nrask/raw/master/LICENSE',
    maintainer='Guilherme Nemeth',
    maintainer_email='guilherme.nemeth@gmail.com',
    name='nrask',
    packages=find_packages(),
    url='https://bitbucket.org/habboi/nrask',
    version="0.0.116"
)
